-- Mentioned in the TODO file is that I want to do away with the ugly
-- unique column names and use plain words instead. Also mentioned is
-- the desire to improve the Transport and Alias tables. This is the
-- result: what the new schema should be. It surprised me!
--
PRAGMA foreign_keys=ON;
BEGIN TRANSACTION;
--
CREATE TABLE "Transport" (key INTEGER PRIMARY KEY,
	active INTEGER DEFAULT 1, transport TEXT, nexthop INTEGER,
	mx INTEGER DEFAULT 1, port INTEGER,
	UNIQUE (transport,nexthop,mx,port));
-- Transport.nexthop would be a pointer to Domain.key, but without a
-- foreign key constraint, because the Domain table has yet to be
-- created at this point.
--
CREATE TABLE "RClass" (key INTEGER PRIMARY KEY,
	name TEXT, UNIQUE(name));
-- This revision removes the NOT NULL constraint from RClass.name; we
-- will insert a special record RClass.key=-1 with RClass.name=NULL,
-- which thus maintains a defacto NOT NULL constraint for other rows.
INSERT INTO "RClass" VALUES(-1,NULL);
--
CREATE TABLE "Domain" (key INTEGER PRIMARY KEY, name TEXT,
	active INTEGER DEFAULT 1, class INTEGER DEFAULT 0,
	sysuser INTEGER DEFAULT 0, transport INTEGER,
	rclass INTEGER DEFAULT 30, UNIQUE (name),
	FOREIGN KEY(transport) REFERENCES Transport(key)
	FOREIGN KEY(rclass) REFERENCES RClass(key));
-- This revision removes the NOT NULL constraint from Domain.name; we
-- will insert a special record Domain.key=0 with Domain.name=NULL,
-- which thus maintains a defacto NOT NULL constraint for other rows.
INSERT INTO "Domain" VALUES(0,NULL,NULL,NULL,NULL,NULL,NULL);
--
CREATE TABLE "Address" (key INTEGER PRIMARY KEY,
	localpart TEXT NOT NULL, domain INTEGER NOT NULL,
	active INTEGER DEFAULT 1, transport INTEGER, rclass INTEGER,
	FOREIGN KEY(domain) REFERENCES Domain(key),
	FOREIGN KEY(transport) REFERENCES Transport(key),
	FOREIGN KEY(rclass) REFERENCES RClass(key),
	UNIQUE (localpart, domain));
-- We will insert a special record Address.key=0 with Address.domain=0
-- to differentiate aliases(5) commands, paths or includes from
-- address targets.
INSERT INTO "Address" VALUES(0,'',0,NULL,NULL,NULL);
--
CREATE TABLE "Alias" (key INTEGER PRIMARY KEY,
	address INTEGER NOT NULL, active INTEGER DEFAULT 1,
	target INTEGER NOT NULL, exten TEXT,
	FOREIGN KEY(address) REFERENCES Address(key)
	FOREIGN KEY(target) REFERENCES Address(key));
-- This revision changes Alias.name to Alias.address, because an INTEGER
-- field should not be called "name" (to me that implies TEXT.) If
-- Alias.target=0, that tells us that the Alias.exten field contains a
-- /file/name, or a |command, or an :include:/file/name. Otherwise,
-- Alias.exten is the same as it was in the VAlias table. WAS, because
-- now that the definition is the same, VAlias is gone! Alias.active as
-- another tri-state field will differentiate local(8) aliases(5) from
-- virtual(5).
--
CREATE TABLE "VMailbox" (key INTEGER PRIMARY KEY,
	active INTEGER DEFAULT 1, password TEXT, home TEXT,
	uid INTEGER, gid INTEGER,
	FOREIGN KEY(key) REFERENCES Address(key));
--
CREATE TABLE "BScat" (key INTEGER PRIMARY KEY,
	sender TEXT NOT NULL, priority INTEGER,
	target TEXT NOT NULL, UNIQUE (sender, priority));
--
COMMIT;
